@@ -4,6 +4,7 @@ import (
 	"encoding/json"
 	"io/ioutil"
 	"testing"
+	"time"
 
 	"github.com/snyk/driftctl/pkg/filter"
 	"github.com/stretchr/testify/mock"
@@ -1269,7 +1270,10 @@ func addSchemaToRes(res *resource.Resource, repo resource.SchemaRepositoryInterf
 
 func TestAnalysis_MarshalJSON(t *testing.T) {
 	goldenFile := "./testdata/output.json"
-	analysis := Analysis{}
+	analysis := Analysis{
+		Duration: 241 * time.Second,
+	}
+	analysis.SetIaCSourceCount(1)
 	analysis.AddManaged(
 		&resource.Resource{
 			Id:   "AKIA5QYBVVD25KFXJHYJ",
@@ -1349,12 +1353,16 @@ func TestAnalysis_MarshalJSON(t *testing.T) {
 
 func TestAnalysis_UnmarshalJSON(t *testing.T) {
 	expected := Analysis{
+		options: AnalyzerOptions{
+			Deep: true,
+		},
 		summary: Summary{
-			TotalResources: 6,
-			TotalDrifted:   1,
-			TotalUnmanaged: 2,
-			TotalDeleted:   2,
-			TotalManaged:   2,
+			TotalResources:      6,
+			TotalDrifted:        1,
+			TotalUnmanaged:      2,
+			TotalDeleted:        2,
+			TotalManaged:        2,
+			TotalIaCSourceCount: 3,
 		},
 		managed: []*resource.Resource{
 			{
@@ -1425,12 +1433,14 @@ func TestAnalysis_UnmarshalJSON(t *testing.T) {
 		t.Fatal(err)
 	}
 	assert.Equal(t, expected, got)
+	assert.True(t, got.Options().Deep)
 	assert.Equal(t, 33, got.Coverage())
 	assert.Equal(t, 2, got.Summary().TotalUnmanaged)
 	assert.Equal(t, 2, got.Summary().TotalManaged)
 	assert.Equal(t, 2, got.Summary().TotalDeleted)
 	assert.Equal(t, 6, got.Summary().TotalResources)
 	assert.Equal(t, 1, got.Summary().TotalDrifted)
+	assert.Equal(t, uint(3), got.Summary().TotalIaCSourceCount)
 	assert.Len(t, got.alerts, 1)
 	assert.Equal(t, got.alerts["aws_iam_access_key"][0].Message(), "This is an alert")
 }
