@@ -161,6 +161,8 @@ func TestTerraformStateReader_AWS_Resources(t *testing.T) {
 		{name: "Api Gateway vpc link", dirName: "aws_api_gateway_vpc_link", wantErr: false},
 		{name: "Api Gateway V2 Api", dirName: "aws_apigatewayv2_api", wantErr: false},
 		{name: "Api Gateway V2 Route", dirName: "aws_apigatewayv2_route", wantErr: false},
+		{name: "Api Gateway V2 Deployment", dirName: "aws_apigatewayv2_deployment", wantErr: false},
+		{name: "Api Gateway V2 stage", dirName: "aws_apigatewayv2_stage", wantErr: false},
 		{name: "Api Gateway request validator", dirName: "aws_api_gateway_request_validator", wantErr: false},
 		{name: "Api Gateway rest api policy", dirName: "aws_api_gateway_rest_api_policy", wantErr: false},
 		{name: "Api Gateway base path mapping", dirName: "aws_api_gateway_base_path_mapping", wantErr: false},
@@ -171,14 +173,23 @@ func TestTerraformStateReader_AWS_Resources(t *testing.T) {
 		{name: "Api Gateway method settings", dirName: "aws_api_gateway_method_settings", wantErr: false},
 		{name: "Api Gateway integration", dirName: "aws_api_gateway_integration", wantErr: false},
 		{name: "Api Gateway integration response", dirName: "aws_api_gateway_integration_response", wantErr: false},
+		{name: "Api Gateway V2 Api", dirName: "aws_apigatewayv2_api", wantErr: false},
+		{name: "Api Gateway V2 Route", dirName: "aws_apigatewayv2_route", wantErr: false},
 		{name: "Api Gateway V2 authorizer", dirName: "aws_apigatewayv2_authorizer", wantErr: false},
+		{name: "Api Gateway V2 integration", dirName: "aws_apigatewayv2_integration", wantErr: false},
+		{name: "Api Gateway V2 model", dirName: "aws_apigatewayv2_model", wantErr: false},
+		{name: "Api Gateway V2 stage", dirName: "aws_apigatewayv2_stage", wantErr: false},
+		{name: "App gateway v2 vpc link", dirName: "aws_apigatewayv2_vpc_link", wantErr: false},
+		{name: "App gateway v2 route response", dirName: "aws_apigatewayv2_route_response", wantErr: false},
+		{name: "Api Gateway V2 mapping", dirName: "aws_apigatewayv2_api_mapping", wantErr: false},
+		{name: "App gateway v2 domain name", dirName: "aws_apigatewayv2_domain_name", wantErr: false},
+		{name: "Api Gateway V2 integration response", dirName: "aws_apigatewayv2_integration_response", wantErr: false},
 		{name: "AppAutoScaling Targets", dirName: "aws_appautoscaling_target", wantErr: false},
 		{name: "network acl", dirName: "aws_network_acl", wantErr: false},
 		{name: "network acl rule", dirName: "aws_network_acl_rule", wantErr: false},
 		{name: "default network acl", dirName: "aws_default_network_acl", wantErr: false},
 		{name: "App autoscaling policy", dirName: "aws_appautoscaling_policy", wantErr: false},
 		{name: "App autoscaling scheduled action", dirName: "aws_appautoscaling_scheduled_action", wantErr: false},
-		{name: "App gateway v2 vpc link", dirName: "aws_apigatewayv2_vpc_link", wantErr: false},
 		{name: "Launch template", dirName: "aws_launch_template", wantErr: false},
 		{name: "Launch configuration", dirName: "aws_launch_configuration", wantErr: false},
 	}
