@@ -5,7 +5,7 @@ import (
 	"sync"
 	"testing"
 
-	"github.com/cloudskiff/driftctl/pkg/resource"
+	"github.com/snyk/driftctl/pkg/resource"
 	"github.com/stretchr/testify/assert"
 )
 
