@@ -12,7 +12,7 @@ import (
 	"github.com/snyk/driftctl/test/acceptance/awsutils"
 )
 
-func TestAcc_AwsSNSTopicSubscription(t *testing.T) {
+func TestAcc_Aws_SNSTopicSubscription(t *testing.T) {
 	acceptance.Run(t, acceptance.AccTestCase{
 		TerraformVersion: "0.15.5",
 		Paths:            []string{"./testdata/acc/aws_sns_topic_subscription"},
