@@ -63,4 +63,6 @@ func InitResourcesMetadata(resourceSchemaRepository resource.SchemaRepositoryInt
 	initAwsAppAutoscalingTargetMetaData(resourceSchemaRepository)
 	initAwsAppAutoscalingPolicyMetaData(resourceSchemaRepository)
 	initAwsLaunchTemplateMetaData(resourceSchemaRepository)
+	initAwsApiGatewayV2ModelMetaData(resourceSchemaRepository)
+	initAwsApiGatewayV2MappingMetaData(resourceSchemaRepository)
 }
