@@ -3,9 +3,9 @@ package google
 import (
 	"testing"
 
-	"github.com/cloudskiff/driftctl/pkg/resource"
-	tf "github.com/cloudskiff/driftctl/pkg/terraform"
-	testresource "github.com/cloudskiff/driftctl/test/resource"
+	"github.com/snyk/driftctl/pkg/resource"
+	tf "github.com/snyk/driftctl/pkg/terraform"
+	testresource "github.com/snyk/driftctl/test/resource"
 	"github.com/stretchr/testify/assert"
 )
 
@@ -30,6 +30,7 @@ func TestGoogle_Metadata_Flags(t *testing.T) {
 		GoogleBigTableInstanceResourceType:        {},
 		GoogleComputeGlobalAddressResourceType:    {},
 		GoogleCloudRunServiceResourceType:         {},
+		GoogleComputeNodeGroupResourceType:        {},
 	}
 
 	schemaRepository := testresource.InitFakeSchemaRepository(tf.GOOGLE, "3.78.0")
