@@ -20,6 +20,7 @@ type telemetry struct {
 	TotalManaged   int    `json:"total_managed"`
 	Duration       uint   `json:"duration"`
 	ProviderName   string `json:"provider_name"`
+	IaCSourceCount uint   `json:"iac_source_count"`
 }
 
 type Telemetry struct {
@@ -59,6 +60,10 @@ func (te Telemetry) SendTelemetry(store memstore.Bucket) {
 		t.ProviderName = val
 	}
 
+	if val, ok := store.Get("iac_source_count").(uint); ok {
+		t.IaCSourceCount = val
+	}
+
 	body, err := json.Marshal(t)
 	if err != nil {
 		logrus.Debug(err)
